# Tcl

To use this language, use the class "language-tcl".

## Comments

    # This is a comment

## Strings

    "foo \"bar\" baz"
    "foo\
    bar\
    baz"

## Variables

    $foo
    $foo::bar_42
    $::baz
    ${foobar}
    set foo::bar "baz"

## Functions

    proc foobar {baz} {
    	puts $baz
    }

    proc RESTORE/post/:post_id/comment/:comment_id {post_id comment_id} {
        #| Restore a comment handler
        comment_restore $comment_id
        qc::actions redirect [url "/post/$post_id" show_deleted_comment_ids $comment_id]
    }

## Known failures

There are certain edge cases where Prism will fail. There are always such cases in every regex-based syntax highlighter. However, Prism dares to be open and honest about them. If a failure is listed here, it doesn’t mean it will never be fixed. This is more of a “known bugs” list, just with a certain type of bug.

### Comment-like substrings

    "This string is #broken"